@@ -1,9 +1,6 @@
 
 context("call_function")
 
-## We don't use this, so no need to test currently
-return()
-
 test_that("nested event loops", {
   ## Create a function that finishes while its event loop is inactive
   sleeper <- function(x) { Sys.sleep(x); Sys.getpid() }
